pybedtools.cbedtools.Interval
=============================

.. currentmodule:: pybedtools.cbedtools

.. autoclass:: Interval

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Interval.append
      ~Interval.deparse_attrs
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Interval.attrs
      ~Interval.chrom
      ~Interval.count
      ~Interval.end
      ~Interval.fields
      ~Interval.file_type
      ~Interval.length
      ~Interval.name
      ~Interval.o_amt
      ~Interval.o_end
      ~Interval.o_start
      ~Interval.score
      ~Interval.start
      ~Interval.stop
      ~Interval.strand
   
   